==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/igr-annotation-layer.js <==
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint, ensureEnum, toDoubleCollection, fromDoubleCollection } from "igniteui-react-core";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
export class IgrAnnotationLayer extends IgrSeries {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets whether this series should take up an index for auto brush coloring.
    */
    get useIndex() {
        return this.i.un;
    }
    set useIndex(v) {
        this.i.un = ensureBool(v);
    }
    /**
     * Gets or sets whether this series interacts with the chart legend.
    */
    get useLegend() {
        return this.i.uo;
    }
    set useLegend(v) {
        this.i.uo = ensureBool(v);
    }
    /**
     * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
     * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
    */
    get cursorPosition() {
        return fromPoint(this.i.wy);
    }
    set cursorPosition(v) {
        this.i.wy = toPoint(v);
    }
    /**
     * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
    */
    get isDefaultCrosshairDisabled() {
        return this.i.ui;
    }
    set isDefaultCrosshairDisabled(v) {
        this.i.ui = ensureBool(v);
    }
    /**
     * Gets whether or not the default crosshair behavior is disabled.
    */
    get isDefaultCrosshairBehaviorDisabled() {
        return this.i.ef;
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get appearanceMode() {
        return this.i.t4;
    }
    set appearanceMode(v) {
        this.i.t4 = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualAppearanceMode() {
        return this.i.t1;
    }
    set actualAppearanceMode(v) {
        this.i.t1 = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get shiftAmount() {
        return this.i.u1;
    }
    set shiftAmount(v) {
        this.i.u1 = +v;
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get actualShiftAmount() {
        return this.i.uq;
    }
    set actualShiftAmount(v) {
        this.i.uq = +v;
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get horizontalAppearanceMode() {
        return this.i.ub;
    }
    set horizontalAppearanceMode(v) {
        this.i.ub = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualHorizontalAppearanceMode() {
        return this.i.t2;
    }
    set actualHorizontalAppearanceMode(v) {
        this.i.t2 = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get verticalAppearanceMode() {
        return this.i.uc;
    }
    set verticalAppearanceMode(v) {
        this.i.uc = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualVerticalAppearanceMode() {
        return this.i.t3;
    }
    set actualVerticalAppearanceMode(v) {
        this.i.t3 = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get horizontalShiftAmount() {
        return this.i.u0;
    }
    set horizontalShiftAmount(v) {
        this.i.u0 = +v;
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get actualHorizontalShiftAmount() {
        return this.i.up;
    }
    set actualHorizontalShiftAmount(v) {
        this.i.up = +v;
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get verticalShiftAmount() {
        return this.i.u2;
    }
    set verticalShiftAmount(v) {
        this.i.u2 = +v;
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get actualVerticalShiftAmount() {
        return this.i.ur;
    }
    set actualVerticalShiftAmount(v) {
        this.i.ur = +v;
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get horizontalDashArray() {
        return fromDoubleCollection(this.i.wv);
    }
    set horizontalDashArray(v) {
        this.i.wv = toDoubleCollection(v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualHorizontalDashArray() {
        return fromDoubleCollection(this.i.wp);
    }
    set actualHorizontalDashArray(v) {
        this.i.wp = toDoubleCollection(v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get verticalDashArray() {
        return fromDoubleCollection(this.i.ww);
    }
    set verticalDashArray(v) {
        this.i.ww = toDoubleCollection(v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualVerticalDashArray() {
        return fromDoubleCollection(this.i.wq);
    }
    set actualVerticalDashArray(v) {
        this.i.wq = toDoubleCollection(v);
    }
    /**
     * Gets if the series uses an index, which can be used to auto-assign it a color.
    */
    get isIndexed() {
        return this.i.et;
    }
    /**
     * Gets if the series should appear in any legends.
    */
    get isUsableInLegend() {
        return this.i.isUsableInLegend;
    }
    /**
     * Gets whether this series is an annotation layer.
    */
    get isAnnotationLayer() {
        return this.i.d6;
    }
    /**
     * Gets or sets whether this layer renders as an overlay or not.
    */
    get shouldRenderAsOverlay() {
        return this.i.um;
    }
    set shouldRenderAsOverlay(v) {
        this.i.um = ensureBool(v);
    }
}

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/igr-annotation-layer.js <==
import { AnnotationAppearanceMode_$type } from "./AnnotationAppearanceMode";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint, ensureEnum, toDoubleCollection, fromDoubleCollection } from "igniteui-react-core";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
export class IgrAnnotationLayer extends IgrSeries {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets whether this series should take up an index for auto brush coloring.
    */
    get useIndex() {
        return this.i.xf;
    }
    set useIndex(v) {
        this.i.xf = ensureBool(v);
    }
    /**
     * Gets or sets whether this series interacts with the chart legend.
    */
    get useLegend() {
        return this.i.xg;
    }
    set useLegend(v) {
        this.i.xg = ensureBool(v);
    }
    /**
     * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
     * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
    */
    get cursorPosition() {
        return fromPoint(this.i.zq);
    }
    set cursorPosition(v) {
        this.i.zq = toPoint(v);
    }
    /**
     * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
    */
    get isDefaultCrosshairDisabled() {
        return this.i.xa;
    }
    set isDefaultCrosshairDisabled(v) {
        this.i.xa = ensureBool(v);
    }
    /**
     * Gets whether or not the default crosshair behavior is disabled.
    */
    get isDefaultCrosshairBehaviorDisabled() {
        return this.i.e0;
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get appearanceMode() {
        return this.i.ww;
    }
    set appearanceMode(v) {
        this.i.ww = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualAppearanceMode() {
        return this.i.wt;
    }
    set actualAppearanceMode(v) {
        this.i.wt = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get shiftAmount() {
        return this.i.xt;
    }
    set shiftAmount(v) {
        this.i.xt = +v;
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get actualShiftAmount() {
        return this.i.xi;
    }
    set actualShiftAmount(v) {
        this.i.xi = +v;
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get horizontalAppearanceMode() {
        return this.i.w3;
    }
    set horizontalAppearanceMode(v) {
        this.i.w3 = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualHorizontalAppearanceMode() {
        return this.i.wu;
    }
    set actualHorizontalAppearanceMode(v) {
        this.i.wu = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get verticalAppearanceMode() {
        return this.i.w4;
    }
    set verticalAppearanceMode(v) {
        this.i.w4 = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualVerticalAppearanceMode() {
        return this.i.wv;
    }
    set actualVerticalAppearanceMode(v) {
        this.i.wv = ensureEnum(AnnotationAppearanceMode_$type, v);
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get horizontalShiftAmount() {
        return this.i.xs;
    }
    set horizontalShiftAmount(v) {
        this.i.xs = +v;
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get actualHorizontalShiftAmount() {
        return this.i.xh;
    }
    set actualHorizontalShiftAmount(v) {
        this.i.xh = +v;
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get verticalShiftAmount() {
        return this.i.xu;
    }
    set verticalShiftAmount(v) {
        this.i.xu = +v;
    }
    /**
     * Gets or sets the percentage amount to shift the appearance mode by. Value must range between -1.0 to 1.0.
    */
    get actualVerticalShiftAmount() {
        return this.i.xj;
    }
    set actualVerticalShiftAmount(v) {
        this.i.xj = +v;
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get horizontalDashArray() {
        return fromDoubleCollection(this.i.zn);
    }
    set horizontalDashArray(v) {
        this.i.zn = toDoubleCollection(v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualHorizontalDashArray() {
        return fromDoubleCollection(this.i.zh);
    }
    set actualHorizontalDashArray(v) {
        this.i.zh = toDoubleCollection(v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get verticalDashArray() {
        return fromDoubleCollection(this.i.zo);
    }
    set verticalDashArray(v) {
        this.i.zo = toDoubleCollection(v);
    }
    /**
     * Gets or sets the mode used for shifting the annotation layer color based on the target series.
    */
    get actualVerticalDashArray() {
        return fromDoubleCollection(this.i.zi);
    }
    set actualVerticalDashArray(v) {
        this.i.zi = toDoubleCollection(v);
    }
    /**
     * Gets if the series uses an index, which can be used to auto-assign it a color.
    */
    get isIndexed() {
        return this.i.ff;
    }
    /**
     * Gets if the series should appear in any legends.
    */
    get isUsableInLegend() {
        return this.i.isUsableInLegend;
    }
    /**
     * Gets whether this series is an annotation layer.
    */
    get isAnnotationLayer() {
        return this.i.er;
    }
    /**
     * Gets or sets whether this layer renders as an overlay or not.
    */
    get shouldRenderAsOverlay() {
        return this.i.xe;
    }
    set shouldRenderAsOverlay(v) {
        this.i.xe = ensureBool(v);
    }
}
